#
# spec file for package kradio
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without ffmpeg
%bcond_without lame

Name:           kradio
Version:        4.0.8
Release:        lp150.2.2
Summary:        AM/FM Application for KDE 4
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            http://kradio.sourceforge.net
Source:         http://sourceforge.net/projects/kradio/files/kradio/%{version}/kradio4-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE suse_docdir.patch -- Use openSUSE default doc directory
Patch0:         suse_docdir.patch
BuildRequires:  alsa-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  fdupes
BuildRequires:  libkde4-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libvorbis-devel
BuildRequires:  lirc-devel
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libswresample)
%endif
BuildRequires:  libmms-devel
%if %{with lame}
BuildRequires:  libmp3lame-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%kde4_runtime_requires

%description
Comfortable AM/FM Application for KDE4

KRadio currently provides:

* V4L/V4L2 Radio support
* DBus support
* RDS support
* PVR support
* Remote Control support (LIRC)
* Alarms, Sleep Countdown
* Several GUI Controls (Docking Menu, Station Quickbar, Radio Display,
  Shortcuts)
* Timeshifter Capability
* Recording Capabilities (mp3, ogg/vorbis, wav, ...)
* Extendable Plugin Architecture

This package also includes a growing collection of station preset
files for many cities around the world contributed by KRadio Users.

%prep
%setup -q -n kradio4-%{version}
%patch0 -p1

%build
%if %{with ffmpeg}
%cmake_kde4 -d build
%else
%cmake_kde4 -d build -- -DWITH_FFMPEG=OFF
%endif
%make_jobs

%install
%kde4_makeinstall -C build
%suse_update_desktop_file -G "KDE Radio Tuner" kradio4 AudioVideo Tuner
%kde_post_install
%fdupes -s %{buildroot}
%find_lang kradio4 --all-name

%files -f kradio4.lang
%defattr(-,root,root,-)
%{_datadir}/pixmaps/kradio4.png
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/INSTALL
%{_kde4_applicationsdir}/kradio4.desktop
%{_kde4_appsdir}/kradio4/
%{_kde4_bindir}/kradio4
%{_kde4_bindir}/kradio4-convert-presets
%dir %{_kde4_iconsdir}/hicolor/24x24
%dir %{_kde4_iconsdir}/hicolor/24x24/apps
%dir %{_kde4_iconsdir}/hicolor/256x256
%dir %{_kde4_iconsdir}/hicolor/256x256/actions
%dir %{_kde4_iconsdir}/hicolor/330x330
%dir %{_kde4_iconsdir}/hicolor/330x330/actions
%dir %{_kde4_iconsdir}/locolor/24x24
%dir %{_kde4_iconsdir}/locolor/24x24/apps
%{_kde4_iconsdir}/??color/*/*/*.png
%{_kde4_libdir}/kradio4/

%changelog
* Wed Mar  7 2018 wbauer@tmo.at
- Build with lame for MP3 support
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Mon Jul 25 2016 olaf@aepfle.de
- Unconditionally build with ffmpeg
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Fri Jan 30 2015 asterios.dramis@gmail.com
- Update to version 4.0.8:
  * updated Czech translation
  * fixed handling of alsa devices without mixer elements
  * enabled internet radio reconnect-watchdog with default timeout 4s
  * fixed Qt include paths for Ubuntu
  * fixed build dependencies in CMakeLists.txt and Debian/SuSE/Fedora build
    scripts
  * cleaned backlog of translation & preset emails
  * suspend-on-sleep feature added
  * fixed alarm time slip after suspend
  * updated for recent libav/libffmpeg
  * updated German translation
  * QString -> char* conversion fixes
  * various Build system fixes
  * various misc / conformance fixes
  * updated Italian translation
  * MPRIS Plugin
  * various build system fixes
  * various misc/i18n-conformance improvements
  * updated Russian translation
  * fixed compilation problems in Serbian translation
  * added more parts of Slovak translation
  * added Serbian (Latin) translation
  * fixed German translation for recent text string changes
- Added new build requirement alsa-devel.
- Added optional build requirement lame.
- Removed explicitly_add_qtcore_includes.patch (fixed upstream).
- Rebased suse_docdir.patch to apply cleanly.
* Thu Jan  2 2014 hrvoje.senjan@gmail.com
- added patches:
  * explicitly_add_qtcore_includes.patch: fixes build with newer
    kdelibs versions, as includes are now prefered without qtmodule
* Sat Feb 16 2013 asterios.dramis@gmail.com
- Update to version 4.0.7:
  * fix for planar sound sample formats in very recent ffmpeg releases
  * support for id3 tags in recording configuration
  * fixed segfault in case sample format is unknown
  * fixed charset/encoding of id3 tags / vorbis comments
* Thu Aug 16 2012 mlin@suse.com
- Update to version 4.0.6
  * bugfixes for playlist file .pls handling
  * support for WMV playlists
  * improved playlist type autodetection
* Fri Aug 10 2012 mlin@suse.com
- Update to version 4.0.5
  * bugfix for http error handling in playlist handler
  * cleanup of internet radio libffmpeg/libav code
  * fixed watchdog handling: it was not stopped during station change and caused
    accessing emptyplaylists, thus div/0
  * removing cr/lf in ICY meta data / RDS data for running text in GUI
  * fixed typo in escape sequence code for ICY meta data parsing
  * fixed content-type handling for mms streams (allows now skipping slow autodetection)
  * finally fixed the problem with skips and stops in internet radio stream decoding
  * fixed handling of HTTP 304 (not modified) response code
  * updated preset file for RioDeJaneiro/Brazil
  * initial partial Slovak translation
  * added watchdog for internet streams: reconnects after a configurable stall time
  * visualization of disabled alarms
  * endianess and sample conversion code speedup
  * disabled alsa blocking usleep workaround by default and added configuration option
  * updated German translation
  * added config option for internet radio stations to set metadata encoding charsets
  * further buffer management fixes to stop repeated skips on certain systems
  * individual name for quickbar window title
  * Czech translation update
  * spec file updates
* Mon Apr  2 2012 mlin@suse.com
- fix build fail with directories not owned by a package
* Sun Feb 19 2012 ctrippe@opensuse.org
- update to 4.0.4
  * improved shoutcast support: fixed "Accept:" HTTP header field
  * issue warning if a broken V4L2 kernel is detected
  * fixed buffer alignment issue to avoid alignment-error segfault
    in libffmpeg sse2 code
- update to 4.0.3
  * major rework of internet radio stream handling: support for
    shoutcast http icy protocol extensions (RDS-like meta data
    support)
  * improved running text in radio display
  * eliminated ancient workarounds in docking menu
  * fixes for docking menue issues on Ubuntu
  * fixed stuttering playback on Ubuntu
  * working FLV support (simply based on libffmpeg, but many thanks
    to Paulo Cavalcanti for reporting/debungging/testing!)
  * libffmpeg fixes for recent deprecations
  * German translation fixes
  * fixed UI files
  * segfault and compatibility fixes with recent libav / libffmpeg
  * workaround for problem with high cpu load during blocking ALSA
    pcm writes (ALSA seems to poll to a certain degree)
  * fixed reading of radio card name
  * Added partial spanish translation
  * fixed save/restore of mixer settings
  * fixed wrong handling of prepare/releaseCapture in v4l
  * partial Turkish translation
  * more parts for Spanish translation
  * started to complete Spanish translation
  * Czech translation update
  * Ukrainian translation update
  * Italian translation
  * fix of desktop icon
- Removed outdated obsoletes/provides added for the KDE4 transition
- Remove patch for desktop file, was fixed upstream
* Fri Sep 16 2011 toddrme2178@gmail.com
- Fixed self-obsoletes (fix for RPMLINT warning)
- Added ffmpeg optional buildrequires (needed for streaming support)
- Cleaned up spec file formatting
* Tue Sep 13 2011 idonmez@suse.com
- Fix tarball URL
* Sat Jan  8 2011 dmueller@suse.de
- update to 4.0.2 (bnc#663157):
  - added preset files
  - fixed segfault and problems in internetradio plugin when
    playlists/streams do not load properly
    emw - better configurability for alsa buffer handling plus extra debugging output
  - fixed pause/resume for pulse audio environments
    emw - fixed problem with inapropriately set capture mixer volumes
  - fixed capture/playback mixer list c&p error in v4l plugin
    emw - better error handling in case the opening of an alsa sound device fails
    emw - moved internet radio play list loading from decoder thread to GUI
  - new, currently still disabled method to do the stream downloading
    for internet radio in the main thread asynchronously, not in the
    decoder thread any more. Unfortunately, KDE4 does not yet have
    an kioslave for the mms:// protocol. Thus this method is currently
    still disabled.
  - fixed problem with non-ascii-characters / encoding detection in
    .asx playlists
  - fixed segfault caused by improper way to delete QThread objects
  - check box for v4l config to disable caps check at startup to
    minimize interference with other programs using V4L devices
  - combo box for radio device selection in V4L radio configuration
    (with option to manually add device)
    emw - fixed segfault in ALSA module caused by insufficient checks while
    parsing ALSA device descriptions
  - fixed mix up of pause/resume in dbus plugin
  - dbus plugin can change stations even if power is off
  - stop recording v4l stream when powering off v4l plugin
  - power on before starting recording triggered by system tray icon/menu
  - fixed signal naming mistake in recording configuration dialog
  - internet radio: big rework of playlist download method. should be much cleaner now
* Thu Dec 16 2010 toddrme2178@gmail.com
- Fix LIRC support
* Sun Oct  3 2010 javier@opensuse.org
- package updated to 4.0.1 (bugfix release)
  + internet radio: automatic reconnect if connection is terminated.
    limit time required for autodetection. Parameters
    are currently only configurable in config file,
    will be added to GUI in 4.0.2
  + fixed segfault when opening of internet radio stream fails
  + keep selection in station list editor when ok/apply is pressed
  + updated German internet radio streems part of ARD (WDR, SWR, BR,
    MDR, Radio Bremen, SR, RBB, NDR, HR)
  + ensure station list items visible in station list editor
  + new stations are added at cursor position
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sun Jun 21 2009 highwaystar.ru@gmail.com
- kde4-kradio -> kradio
* Mon Jun  8 2009 highwaystar.ru@gmail.com
- spec file updated to use desktop file included in source
* Tue Jun  2 2009 highwaystar.ru@gmail.com
- package updated to 4.0.0 final version
* Mon May 25 2009 lnussel@suse.de
- lirc -> lirc-devel in BuildRequires
* Mon Apr 27 2009 highwaystar.ru@gmail.com
- package updated to rc4 version
* Mon Apr 20 2009 highwaystar.ru@gmail.com
- package updated to rc3 version
* Thu Apr 16 2009 highwaystar.ru@gmail.com
- package updated to rc2 version
* Tue Mar 31 2009 highwaystar.ru@gmail.com
- package updated to rc1 version
* Fri Mar 20 2009 highwaystar.ru@gmail.com
- package updated to beta2 version
- desktop file fixed
* Mon Mar  9 2009 highwaystar.ru@gmail.com
- package updated to r745 shapshot
- feature: Dbus plugin
- feature: internet radio plugin
* Wed Feb 25 2009 highwaystar.ru@gmail.com
- package updated to 4.0.0 beta1 r664
* Sat Feb 21 2009 highwaystar.ru@gmail.com
- packaged kradio4 version snapshot-2009-02-20-r649 using the buildservice spec file wizard
* Tue Oct 23 2007 stbinner@suse.de
- fix build with gcc 4.3
* Fri May 11 2007 ssommer@suse.de
- fix plugin loading on x86_64 (#217971)
* Tue Oct 31 2006 coolo@suse.de
- update kradio to the latest snapshot after getting advise
  from author
* Tue May 30 2006 adrian@suse.de
- fix build for < 10.1
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 24 2005 stbinner@suse.de
- fix wrong include hints for Qt 3.3.5 compilation
* Thu Oct  6 2005 stbinner@suse.de
- added flac and flac-devel to neededforbuild (required by the new
  libsndfile)
* Tue Aug 30 2005 dmueller@suse.de
- update to 1.0beta3b to make it work with ALSA
* Sat Aug 13 2005 dmueller@suse.de
- update 1.0beta2 which fixes plugin loading and incorporates
  all previous patches (fixes #102926).
* Sat Jul 30 2005 dmueller@suse.de
- update 1.0beta1
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Sep  3 2003 adrian@suse.de
- add AudioVideo Category
* Tue Jul 29 2003 adrian@suse.de
- add Categories
* Sat Jun 14 2003 coolo@suse.de
- package directories
* Fri May 23 2003 coolo@suse.de
- reverting adrian's nonsense
* Fri May 23 2003 adrian@suse.de
- let it build again
* Fri May  2 2003 adrian@suse.de
- update to version 0.2.7a
* Sun Mar  9 2003 adrian@suse.de
- fix .desktop file entries
* Fri Nov  8 2002 coolo@suse.de
- the new kradio maintainer suggests to use CVS for KDE3
  users. Still not many enhancements to the 0.1.2 version
  as far as I can see
* Thu May 23 2002 adrian@suse.de
- use update_admin
* Mon Nov 12 2001 ro@suse.de
- fix for automake 1.5
* Fri Nov  9 2001 adrian@suse.de
- use kde2-devel-packages
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Fri Aug 10 2001 adrian@suse.de
- autoconf 2.52 fixes
* Thu Jun 21 2001 adrian@suse.de
- make it autoconf 2.50 ready
- disable documentation until kde 2.2
* Thu May 10 2001 adrian@suse.de
- fix wrong Type in desktop file
* Sun Apr  8 2001 adrian@suse.de
- New version 0.1.2
* Sat Apr  7 2001 kukuk@suse.de
- Fix neededforbuild
* Mon Mar 19 2001 adrian@suse.de
- Spec file created from kradio-0.1.tar.bz2 by autospec
